get_dtb: Query the Brazilian Territorial Division

View source: R/get_dtb_info.R

get_dtbR Documentation

Query the Brazilian Territorial Division

Description

Looks up territorial identifiers and their hierarchy in the version of the Brazilian Territorial Division (DTB) shipped with the package.

Usage

get_dtb(code = NULL, name = NULL)

Arguments

code

Optional vector of IBGE territorial codes.

name

Optional vector of territory names. Matching ignores case and surrounding whitespace.

Value

A data frame. If both arguments are 'NULL', the complete table is returned. If both are supplied, rows matching either condition are returned.

References

https://www.ibge.gov.br/geociencias/organizacao-do-territorio/estrutura-territorial/23701-divisao-territorial-brasileira.html

See Also

[get_dtb_levels()]

Examples

get_dtb(code = c(50, 5002704, 1))
get_dtb(name = c("Campo Grande", "Recife"))

brazilmaps documentation built on Aug. 4, 2026, 5:07 p.m.