get_dtb_levels: Relate levels of the Brazilian Territorial Division

View source: R/get_dtb_lvl.R

get_dtb_levelsR Documentation

Relate levels of the Brazilian Territorial Division

Description

Returns codes and names for one or more territorial levels using the hierarchy shipped with the package.

Usage

get_dtb_levels(
  levels = c("municipality", "state", "region", "immediate_region",
    "intermediate_region", "microregion", "mesoregion"),
  filters = NULL
)

Arguments

levels

Character vector containing any of '"municipality"', '"state"', '"region"', '"immediate_region"', '"intermediate_region"', '"microregion"' and '"mesoregion"'.

filters

Optional named list of codes used to filter the result. Conditions are combined with logical AND.

Value

A data frame with explicit code/name pairs for the requested levels.

References

https://www.ibge.gov.br/geociencias/organizacao-do-territorio/estrutura-territorial/23701-divisao-territorial-brasileira.html

See Also

[get_dtb()]

Examples

get_dtb_levels(c("municipality", "region"))
get_dtb_levels(c("state", "immediate_region"))

brazilmaps documentation built on Aug. 4, 2026, 5:07 p.m.