| brmap_editions | R Documentation |
Returns the inventory generated with the spatial files. The package bundles the latest official edition from each consecutive run with the same municipality count. All listed editions are installed and read locally by [get_brmap()].
brmap_editions()
brmap_years()
A data frame with edition year, feature count, file size, checksum, source and processing metadata.
brmap_editions()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.