| get_dtb | R Documentation |
Looks up territorial identifiers and their hierarchy in the version of the Brazilian Territorial Division (DTB) shipped with the package.
get_dtb(code = NULL, name = NULL)
code |
Optional vector of IBGE territorial codes. |
name |
Optional vector of territory names. Matching ignores case and surrounding whitespace. |
A data frame. If both arguments are 'NULL', the complete table is returned. If both are supplied, rows matching either condition are returned.
[get_dtb_levels()]
get_dtb(code = c(50, 5002704, 1))
get_dtb(name = c("Campo Grande", "Recife"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.