| get_dtb_levels | R Documentation |
Returns codes and names for one or more territorial levels using the hierarchy shipped with the package.
get_dtb_levels(
levels = c("municipality", "state", "region", "immediate_region",
"intermediate_region", "microregion", "mesoregion"),
filters = NULL
)
levels |
Character vector containing any of '"municipality"', '"state"', '"region"', '"immediate_region"', '"intermediate_region"', '"microregion"' and '"mesoregion"'. |
filters |
Optional named list of codes used to filter the result. Conditions are combined with logical AND. |
A data frame with explicit code/name pairs for the requested levels.
[get_dtb()]
get_dtb_levels(c("municipality", "region"))
get_dtb_levels(c("state", "immediate_region"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.